:py:mod:`byma.nuby.Bifurcation`
===============================

.. py:module:: byma.nuby.Bifurcation


Module Contents
---------------

Classes
~~~~~~~

.. autoapisummary::

   byma.nuby.Bifurcation.Bifurcation




.. py:class:: Bifurcation


   Defines default options for the Bifurcation package


